@@ -84,7 +84,7 @@ void MainWindow::refresh() {
         refreshChangePass();
         refreshRename();
         QStringList home_folders = shell->getOutput("ls -1 /home").split("\n");
-        foreach (QString folder, home_folders) {
+        for (const QString &folder : home_folders) {
             if (folder.length() > 1 && folder != "ftp") {
                 if (shell->run("grep -w '^" + folder + "' /etc/passwd >/dev/null") == 0) {
                     comboRenameUser->addItem(folder);
