@@ -1,213 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="fr">
-<context>
-    <name>MConfig</name>
-    <message>
-        <source>none</source>
-        <translation type="vanished">aucun</translation>
-    </message>
-    <message>
-        <source>The user configuration will be repaired. Please close all other applications now. When finished, please logout or reboot. Are you sure you want to repair now?</source>
-        <translation type="vanished">La configuration de l&apos;utilisateur va être modifiée. Veuillez fermer toutes les applications ouvertes. Après exécution, veuillez fermer votre session ou redémarrer votre machine. Êtes-vous sûr(e) de vouloir modifier cette configuration maintenant?</translation>
-    </message>
-    <message>
-        <source>Yes</source>
-        <translation type="vanished">Oui</translation>
-    </message>
-    <message>
-        <source>No</source>
-        <translation type="vanished">Non</translation>
-    </message>
-    <message>
-        <source>Autologin options</source>
-        <translation type="vanished">Options de connexion automatique</translation>
-    </message>
-    <message>
-        <source>Autologin has been disabled for the &apos;%1&apos; account.</source>
-        <translation type="vanished">La connexion automatique a été désactivée pour le compte &apos;%1&apos;.</translation>
-    </message>
-    <message>
-        <source>Autologin has been enabled for the &apos;%1&apos; account.</source>
-        <translation type="vanished">La connexion automatique a été activée pour le compte &apos;%1&apos;.</translation>
-    </message>
-    <message>
-        <source>You must specify a &apos;copy to&apos; destination. You cannot copy to the desktop you are logged in to.</source>
-        <translation type="vanished">Vous devez spécifier une destination pour &quot;copier vers&quot;. Vous ne pouvez pas copier vers le bureau auquel vous êtes connecté.</translation>
-    </message>
-    <message>
-        <source>Before copying, close all other applications. Be sure the copy to destination is large enough to contain the files you are copying. Copying between desktops may overwrite or delete your files or preferences on the destination desktop. Are you sure you want to proceed?</source>
-        <translation type="vanished">Avant de débuter la copie, veuillez fermer toutes les applications ouvertes. Assurez-vous que le répertoire de destination a une taille suffisante pour contenir les fichiers que vous désirez copier. Le processus peut effacer ou écraser vos fichiers ou configurations du bureau de destination. Êtes-vous certain(e) de vouloir continuer?</translation>
-    </message>
-    <message>
-        <source>Synchronizing desktop...</source>
-        <translation type="vanished">Synchronisation des bureaux...</translation>
-    </message>
-    <message>
-        <source>Copying desktop...</source>
-        <translation type="vanished">Copie des bureaux...</translation>
-    </message>
-    <message>
-        <source>The user name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
-        <translation type="vanished">Le nom d&apos;utilisateur doit comporter au moins 2 caractères. Veuillez choisir un nom d&apos;utilisateur plus long avant de continuer.</translation>
-    </message>
-    <message>
-        <source>The user name needs to be lower case and it
-cannot contain special characters or spaces.
-Please choose another name before proceeding.</source>
-        <translation type="vanished">Le nom d&apos;utilisateur doit être en minuscules et il
-ne peut contenir ni caractères spéciaux ni espaces.
-Veuillez choisir un autre nom avant de poursuivre.</translation>
-    </message>
-    <message>
-        <source>Sorry that name is in use. Please select a different name.</source>
-        <translation type="vanished">Désolé, ce nom d&apos;utilisateur est déjà attribué. Veuillez choisir un autre nom d&apos;utilisateur.</translation>
-    </message>
-    <message>
-        <source>Password entries do not match. Please try again.</source>
-        <translation type="vanished">Les mots de passe entrés ne correspondent pas. Veuillez réessayer.</translation>
-    </message>
-    <message>
-        <source>Password needs to be at least 2 characters long. Please enter a longer password before proceeding.</source>
-        <translation type="vanished">Le mot de passe doit contenir au moins 2 caractères. Veuillez entrer un mot de passe plus long avant de poursuivre.</translation>
-    </message>
-    <message>
-        <source>The user was added ok.</source>
-        <translation type="vanished">L&apos;utilisateur a été ajouté avec succès.</translation>
-    </message>
-    <message>
-        <source>Failed to add the user.</source>
-        <translation type="vanished">Ajout de l&apos;utilisateur impossible.</translation>
-    </message>
-    <message>
-        <source>Password successfully changed.</source>
-        <translation type="vanished">Mot de passe modifié avec succès</translation>
-    </message>
-    <message>
-        <source>Failed to change password.</source>
-        <translation type="vanished">La modification du mot de passe a échoué</translation>
-    </message>
-    <message>
-        <source>This action cannot be undone. Are you sure you want to delete user %1?</source>
-        <translation type="vanished">Cette action est irréversible. Êtes-vous sûr(e) de vouloir supprimer l&apos;utilisateur %1?</translation>
-    </message>
-    <message>
-        <source>The user has been deleted.</source>
-        <translation type="vanished">L&apos;utilisateur a été supprimé.</translation>
-    </message>
-    <message>
-        <source>Failed to delete the user.</source>
-        <translation type="vanished">Impossible de supprimer l&apos;utilisateur.</translation>
-    </message>
-    <message>
-        <source>The group name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
-        <translation type="vanished">Le nom du groupe doit être d&apos;au moins 2 caractères. Veuillez sélectionner un nom plus long avant de poursuivre.</translation>
-    </message>
-    <message>
-        <source>The group name needs to be lower case and it 
-cannot contain special characters or spaces.
-Please choose another name before proceeding.</source>
-        <translation type="vanished">Le nom du groupe doit être en minuscules et il
-ne peut contenir ni caractères spéciaux ni espaces.
-Veuillez choisir un autre nom avant de poursuivre.</translation>
-    </message>
-    <message>
-        <source>Sorry that group name already exists. Please select a different name.</source>
-        <translation type="vanished">Désolé, ce nom est déjà utilisé. Veuillez choisir un autre nom.</translation>
-    </message>
-    <message>
-        <source>The system group was added ok.</source>
-        <translation type="vanished">Le groupe du système a bien été ajouté.</translation>
-    </message>
-    <message>
-        <source>Failed to add the system group.</source>
-        <translation type="vanished">Impossible d&apos;ajouter le groupe du système.</translation>
-    </message>
-    <message>
-        <source>This action cannot be undone. Are you sure you want to delete group %1?</source>
-        <translation type="vanished">Cette action est irréversible. Êtes-vous sûr(e) de vouloir supprimer le groupe %1?</translation>
-    </message>
-    <message>
-        <source>The group has been deleted.</source>
-        <translation type="vanished">Le groupe a été supprimé.</translation>
-    </message>
-    <message>
-        <source>Failed to delete the group.</source>
-        <translation type="vanished">Impossible de supprimer le groupe.</translation>
-    </message>
-    <message>
-        <source>The changes have been applied.</source>
-        <translation type="vanished">Les modifications ont été appliquées.</translation>
-    </message>
-    <message>
-        <source>Failed to apply group changes</source>
-        <translation type="vanished">Impossible d&apos;appliquer les changements au groupe</translation>
-    </message>
-    <message>
-        <source>Synchronizing desktop...ok</source>
-        <translation type="vanished">Synchronisation des bureaux...réussie</translation>
-    </message>
-    <message>
-        <source>Copying desktop...ok</source>
-        <translation type="vanished">Copie des bureaux...réussie</translation>
-    </message>
-    <message>
-        <source>Synchronizing desktop...failed</source>
-        <translation type="vanished">Synchronisation des bureaux...échec</translation>
-    </message>
-    <message>
-        <source>Copying desktop...failed</source>
-        <translation type="vanished">Copie des bureaux...échec</translation>
-    </message>
-    <message>
-        <source>browse...</source>
-        <translation type="vanished">Navigation...</translation>
-    </message>
-    <message>
-        <source>Baobab installation</source>
-        <translation type="vanished">Installation de Baobab</translation>
-    </message>
-    <message>
-        <source>Wait while Baobab is installing...</source>
-        <translation type="vanished">Patientez pendant l&apos;installation de Baobab...</translation>
-    </message>
-    <message>
-        <source>About MX User Manager</source>
-        <translation type="vanished">À propos de MX Gestionnaire des utilisateurs</translation>
-    </message>
-    <message>
-        <source>MX User Manager</source>
-        <translation type="vanished">MX Gestionnaire des utilisateurs</translation>
-    </message>
-    <message>
-        <source>Simple user configuration for MX Linux</source>
-        <translation type="vanished">Configuration simple des utilisateurs pour MX Linux </translation>
-    </message>
-    <message>
-        <source>Copyright (c) MX Linux</source>
-        <translation type="vanished">Copyright (c) MX Linux</translation>
-    </message>
-    <message>
-        <source>License</source>
-        <translation type="vanished">Licence</translation>
-    </message>
-    <message>
-        <source>Changelog</source>
-        <translation type="vanished">Journal des modifications</translation>
-    </message>
-    <message>
-        <source>Cancel</source>
-        <translation type="vanished">Annuler</translation>
-    </message>
-    <message>
-        <source>&amp;Close</source>
-        <translation type="vanished">&amp;Fermer</translation>
-    </message>
-    <message>
-        <source>Select folder to copy to</source>
-        <translation type="vanished">Sélectionner le répertoire de destination</translation>
-    </message>
-</context>
 <context>
     <name>MEConfig</name>
     <message>
@@ -228,7 +21,7 @@ Veuillez choisir un autre nom avant de poursuivre.</translation>
     <message>
         <location filename="../mainwindow.ui" line="105"/>
         <source>Add User Account</source>
-        <translation>Ajouter un Compte Utilisateur</translation>
+        <translation>Ajouter un compte utilisateur</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="132"/>
@@ -249,7 +42,7 @@ Veuillez choisir un autre nom avant de poursuivre.</translation>
     <message>
         <location filename="../mainwindow.ui" line="157"/>
         <source>User login name:</source>
-        <translation>Identifiant du nouvel utilisateur:</translation>
+        <translation>Identifiant du nouvel utilisateur :</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="170"/>
@@ -273,7 +66,7 @@ Veuillez choisir un autre nom avant de poursuivre.</translation>
     <message>
         <location filename="../mainwindow.ui" line="192"/>
         <source>User password:</source>
-        <translation>Mot de passe utilisateur:</translation>
+        <translation>Mot de passe utilisateur :</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="205"/>
@@ -290,47 +83,6 @@ Veuillez choisir un autre nom avant de poursuivre.</translation>
         <source>Confirm user password:</source>
         <translation>Confirmer le mot de passe utilisateur :</translation>
     </message>
-    <message>
-        <location filename="../mainwindow.ui" line="359"/>
-        <source>Rename User Account</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="403"/>
-        <source>New user name:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="432"/>
-        <source>Change User Password</source>
-        <translation>Changer le mot de passe utilisateur</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="447"/>
-        <source>new password</source>
-        <translation>Nouveau mot de passe</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="460"/>
-        <source>Confirm new password:</source>
-        <translation>Confirmer le nouveau mot de passe:</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="470"/>
-        <source>confirm new password</source>
-        <translation>confirmer le nouveau mot de passe</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="371"/>
-        <location filename="../mainwindow.ui" line="483"/>
-        <source>Select user to modify:</source>
-        <translation>Sélectionner l&apos;utilisateur à modifier:</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="496"/>
-        <source>New user password:</source>
-        <translation>Nouveau mot de passe utilisateur:</translation>
-    </message>
     <message>
         <location filename="../mainwindow.ui" line="262"/>
         <source>Delete User Account</source>
@@ -365,6 +117,47 @@ Veuillez choisir un autre nom avant de poursuivre.</translation>
         <source>Delete user home directory</source>
         <translation>Supprimer le répertoire home de l&apos;utilisateur</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.ui" line="359"/>
+        <source>Rename User Account</source>
+        <translation>Renommer un compte utilisateur</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="371"/>
+        <location filename="../mainwindow.ui" line="483"/>
+        <source>Select user to modify:</source>
+        <translation>Sélectionner l&apos;utilisateur à modifier :</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="403"/>
+        <source>New user name:</source>
+        <translation>Nouveau nom d&apos;utilisateur : </translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="432"/>
+        <source>Change User Password</source>
+        <translation>Changer le mot de passe utilisateur</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="447"/>
+        <source>new password</source>
+        <translation>Nouveau mot de passe</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="460"/>
+        <source>Confirm new password:</source>
+        <translation>Confirmer le nouveau mot de passe:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="470"/>
+        <source>confirm new password</source>
+        <translation>confirmer le nouveau mot de passe</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="496"/>
+        <source>New user password:</source>
+        <translation>Nouveau mot de passe utilisateur:</translation>
+    </message>
     <message>
         <location filename="../mainwindow.ui" line="527"/>
         <source>Options</source>
@@ -428,14 +221,6 @@ Veuillez choisir un autre nom avant de poursuivre.</translation>
         <source>Alt+G</source>
         <translation>Alt+G</translation>
     </message>
-    <message>
-        <source>Restore APT sources to MX defaults</source>
-        <translation type="vanished">Rétablir la configuration par défaut des sources pour APT </translation>
-    </message>
-    <message>
-        <source>Restore APT sources</source>
-        <translation type="vanished">Rétablir la configuration des sources pour APT </translation>
-    </message>
     <message>
         <location filename="../mainwindow.ui" line="680"/>
         <source>Change Autologin Settings</source>
@@ -486,12 +271,12 @@ Veuillez choisir un autre nom avant de poursuivre.</translation>
     <message>
         <location filename="../mainwindow.ui" line="816"/>
         <source>Copy to:</source>
-        <translation>Copier vers:</translation>
+        <translation>Copier vers :</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="838"/>
         <source>Copy from:</source>
-        <translation>Copier:</translation>
+        <translation>Copier :</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="851"/>
@@ -546,7 +331,7 @@ Veuillez choisir un autre nom avant de poursuivre.</translation>
     <message>
         <location filename="../mainwindow.ui" line="961"/>
         <source>What to copy/sync:</source>
-        <translation>Que faut-il copier/synchoniser:</translation>
+        <translation>Que faut-il copier/synchoniser :</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="977"/>
@@ -692,12 +477,12 @@ Veuillez choisir un autre nom avant de poursuivre.</translation>
         <location filename="../mainwindow.cpp" line="916"/>
         <location filename="../mainwindow.cpp" line="1029"/>
         <source>none</source>
-        <translation type="unfinished">aucun</translation>
+        <translation>aucune</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="262"/>
         <source>The user configuration will be repaired. Please close all other applications now. When finished, please logout or reboot. Are you sure you want to repair now?</source>
-        <translation type="unfinished">La configuration de l&apos;utilisateur va être modifiée. Veuillez fermer toutes les applications ouvertes. Après exécution, veuillez fermer votre session ou redémarrer votre machine. Êtes-vous sûr(e) de vouloir modifier cette configuration maintenant?</translation>
+        <translation>La configuration de l&apos;utilisateur va être modifiée. Veuillez fermer toutes les applications ouvertes. Après exécution, veuillez fermer votre session ou redémarrer votre machine. Êtes-vous sûr(e) de vouloir modifier cette configuration maintenant?</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="263"/>
@@ -705,7 +490,7 @@ Veuillez choisir un autre nom avant de poursuivre.</translation>
         <location filename="../mainwindow.cpp" line="439"/>
         <location filename="../mainwindow.cpp" line="494"/>
         <source>Yes</source>
-        <translation type="unfinished">Oui</translation>
+        <translation>Oui</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="263"/>
@@ -713,49 +498,49 @@ Veuillez choisir un autre nom avant de poursuivre.</translation>
         <location filename="../mainwindow.cpp" line="439"/>
         <location filename="../mainwindow.cpp" line="494"/>
         <source>No</source>
-        <translation type="unfinished">Non</translation>
+        <translation>Non</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="284"/>
         <location filename="../mainwindow.cpp" line="295"/>
         <source>Autologin options</source>
-        <translation type="unfinished">Options de connexion automatique</translation>
+        <translation>Options de connexion automatique</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="285"/>
         <source>Autologin has been disabled for the &apos;%1&apos; account.</source>
-        <translation type="unfinished">La connexion automatique a été désactivée pour le compte &apos;%1&apos;.</translation>
+        <translation>La connexion automatique a été désactivée pour le compte &apos;%1&apos;.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="296"/>
         <source>Autologin has been enabled for the &apos;%1&apos; account.</source>
-        <translation type="unfinished">La connexion automatique a été activée pour le compte &apos;%1&apos;.</translation>
+        <translation>La connexion automatique a été activée pour le compte &apos;%1&apos;.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="307"/>
         <source>You must specify a &apos;copy to&apos; destination. You cannot copy to the desktop you are logged in to.</source>
-        <translation type="unfinished">Vous devez spécifier une destination pour &quot;copier vers&quot;. Vous ne pouvez pas copier vers le bureau auquel vous êtes connecté.</translation>
+        <translation>Vous devez spécifier une destination pour &quot;copier vers&quot;. Vous ne pouvez pas copier vers le bureau auquel vous êtes connecté.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="311"/>
         <source>Before copying, close all other applications. Be sure the copy to destination is large enough to contain the files you are copying. Copying between desktops may overwrite or delete your files or preferences on the destination desktop. Are you sure you want to proceed?</source>
-        <translation type="unfinished">Avant de débuter la copie, veuillez fermer toutes les applications ouvertes. Assurez-vous que le répertoire de destination a une taille suffisante pour contenir les fichiers que vous désirez copier. Le processus peut effacer ou écraser vos fichiers ou configurations du bureau de destination. Êtes-vous certain(e) de vouloir continuer?</translation>
+        <translation>Avant de débuter la copie, veuillez fermer toutes les applications ouvertes. Assurez-vous que le répertoire de destination a une taille suffisante pour contenir les fichiers que vous désirez copier. Le processus peut effacer ou écraser vos fichiers ou configurations du bureau de destination. Êtes-vous certain(e) de vouloir continuer?</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="336"/>
         <source>Synchronizing desktop...</source>
-        <translation type="unfinished">Synchronisation des bureaux...</translation>
+        <translation>Synchronisation des bureaux...</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="338"/>
         <source>Copying desktop...</source>
-        <translation type="unfinished">Copie des bureaux...</translation>
+        <translation>Copie des bureaux...</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="356"/>
         <location filename="../mainwindow.cpp" line="548"/>
         <source>The user name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
-        <translation type="unfinished">Le nom d&apos;utilisateur doit comporter au moins 2 caractères. Veuillez choisir un nom d&apos;utilisateur plus long avant de continuer.</translation>
+        <translation>Le nom d&apos;utilisateur doit comporter au moins 2 caractères. Veuillez choisir un nom d&apos;utilisateur plus long avant de continuer.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="360"/>
@@ -763,222 +548,214 @@ Veuillez choisir un autre nom avant de poursuivre.</translation>
         <source>The user name needs to be lower case and it
 cannot contain special characters or spaces.
 Please choose another name before proceeding.</source>
-        <translation type="unfinished">Le nom d&apos;utilisateur doit être en minuscules et il
+        <translation>Le nom d&apos;utilisateur doit être en minuscules et il
 ne peut contenir ni caractères spéciaux ni espaces.
 Veuillez choisir un autre nom avant de poursuivre.</translation>
     </message>
     <message>
-        <source>Sorry that name is in use. Please select a different name.</source>
-        <translation type="obsolete">Désolé, ce nom d&apos;utilisateur est déjà attribué. Veuillez choisir un autre nom d&apos;utilisateur.</translation>
+        <location filename="../mainwindow.cpp" line="369"/>
+        <source>Sorry, this name is in use. Please enter a different name.</source>
+        <translation>Désolé, ce nom est déjà attribué. Veuillez choisir un nom différent.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="374"/>
         <location filename="../mainwindow.cpp" line="409"/>
         <source>Password entries do not match. Please try again.</source>
-        <translation type="unfinished">Les mots de passe entrés ne correspondent pas. Veuillez réessayer.</translation>
+        <translation>Les mots de passe entrés ne correspondent pas. Veuillez réessayer.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="379"/>
         <location filename="../mainwindow.cpp" line="414"/>
         <source>Password needs to be at least 2 characters long. Please enter a longer password before proceeding.</source>
-        <translation type="unfinished">Le mot de passe doit contenir au moins 2 caractères. Veuillez entrer un mot de passe plus long avant de poursuivre.</translation>
+        <translation>Le mot de passe doit contenir au moins 2 caractères. Veuillez entrer un mot de passe plus long avant de poursuivre.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="396"/>
         <source>The user was added ok.</source>
-        <translation type="unfinished">L&apos;utilisateur a été ajouté avec succès.</translation>
+        <translation>L&apos;utilisateur a été ajouté avec succès.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="400"/>
         <source>Failed to add the user.</source>
-        <translation type="unfinished">Ajout de l&apos;utilisateur impossible.</translation>
+        <translation>Ajout de l&apos;utilisateur impossible.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="428"/>
         <source>Password successfully changed.</source>
-        <translation type="unfinished">Mot de passe modifié avec succès</translation>
+        <translation>Mot de passe modifié avec succès</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="432"/>
         <source>Failed to change password.</source>
-        <translation type="unfinished">La modification du mot de passe a échoué</translation>
+        <translation>La modification du mot de passe a échoué</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="437"/>
         <source>This action cannot be undone. Are you sure you want to delete user %1?</source>
-        <translation type="unfinished">Cette action est irréversible. Êtes-vous sûr(e) de vouloir supprimer l&apos;utilisateur %1?</translation>
+        <translation>Cette action est irréversible. Êtes-vous sûr(e) de vouloir supprimer l&apos;utilisateur %1?</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="450"/>
         <source>The user has been deleted.</source>
-        <translation type="unfinished">L&apos;utilisateur a été supprimé.</translation>
+        <translation>L&apos;utilisateur a été supprimé.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="453"/>
         <source>Failed to delete the user.</source>
-        <translation type="unfinished">Impossible de supprimer l&apos;utilisateur.</translation>
+        <translation>Impossible de supprimer l&apos;utilisateur.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="466"/>
         <source>The group name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
-        <translation type="unfinished">Le nom du groupe doit être d&apos;au moins 2 caractères. Veuillez sélectionner un nom plus long avant de poursuivre.</translation>
+        <translation>Le nom du groupe doit être d&apos;au moins 2 caractères. Veuillez sélectionner un nom plus long avant de poursuivre.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="470"/>
         <source>The group name needs to be lower case and it 
 cannot contain special characters or spaces.
 Please choose another name before proceeding.</source>
-        <translation type="unfinished">Le nom du groupe doit être en minuscules et il
+        <translation>Le nom du groupe doit être en minuscules et il
 ne peut contenir ni caractères spéciaux ni espaces.
 Veuillez choisir un autre nom avant de poursuivre.</translation>
     </message>
     <message>
-        <source>Sorry that group name already exists. Please select a different name.</source>
-        <translation type="obsolete">Désolé, ce nom est déjà utilisé. Veuillez choisir un autre nom.</translation>
+        <location filename="../mainwindow.cpp" line="479"/>
+        <source>Sorry, that group name already exists. Please enter a different name.</source>
+        <translation>Désolé, ce nom de Groupe est déjà utilisé. Veuillez choisir un nom différent.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="486"/>
         <source>The system group was added ok.</source>
-        <translation type="unfinished">Le groupe du système a bien été ajouté.</translation>
+        <translation>Le groupe du système a bien été ajouté.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="489"/>
         <source>Failed to add the system group.</source>
-        <translation type="unfinished">Impossible d&apos;ajouter le groupe du système.</translation>
+        <translation>Impossible d&apos;ajouter le groupe du système.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="492"/>
         <source>This action cannot be undone. Are you sure you want to delete group %1?</source>
-        <translation type="unfinished">Cette action est irréversible. Êtes-vous sûr(e) de vouloir supprimer le groupe %1?</translation>
+        <translation>Cette action est irréversible. Êtes-vous sûr(e) de vouloir supprimer le groupe %1?</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="499"/>
         <source>The group has been deleted.</source>
-        <translation type="unfinished">Le groupe a été supprimé.</translation>
+        <translation>Le groupe a été supprimé.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="502"/>
         <source>Failed to delete the group.</source>
-        <translation type="unfinished">Impossible de supprimer le groupe.</translation>
+        <translation>Impossible de supprimer le groupe.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="523"/>
         <source>The changes have been applied.</source>
-        <translation type="unfinished">Les modifications ont été appliquées.</translation>
+        <translation>Les modifications ont été appliquées.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="526"/>
         <source>Failed to apply group changes</source>
-        <translation type="unfinished">Impossible d&apos;appliquer les changements au groupe</translation>
+        <translation>Impossible d&apos;appliquer les changements au groupe</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="539"/>
         <source>The selected user name is currently in use.</source>
-        <translation type="unfinished"></translation>
+        <translation>Le nom d&apos;utilisateur choisi est déjà attribué.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="540"/>
         <source>To rename this user, please log out and log back in using another user account.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="369"/>
-        <source>Sorry, this name is in use. Please enter a different name.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="479"/>
-        <source>Sorry, that group name already exists. Please enter a different name.</source>
-        <translation type="unfinished"></translation>
+        <translation>Pour modifier le nom de cet utilisateur, déconnectez- vous puis reconnectez-vous sous un autre compte.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="561"/>
         <source>Sorry, this name already exists on your system. Please enter a different name.</source>
-        <translation type="unfinished"></translation>
+        <translation>Désolé, ce nom est déjà attribué sur votre système. Veuillez choisir un nom différent.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="569"/>
         <source>Failed to rename the user. Please make sure that the user is not logged in, you might need to restart</source>
-        <translation type="unfinished"></translation>
+        <translation>Échec lors du renommage. Assurez-vous que l&apos;utilisateur ne soit pas connecté. Vous devrez peut-être redémarrer.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="583"/>
         <source>The user was renamed.</source>
-        <translation type="unfinished"></translation>
+        <translation>Le nom de l&apos;utilisateur a été changé.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="595"/>
         <location filename="../mainwindow.cpp" line="624"/>
         <source>Synchronizing desktop...ok</source>
-        <translation type="unfinished">Synchronisation des bureaux...réussie</translation>
+        <translation>Synchronisation des bureaux...réussie</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="597"/>
         <location filename="../mainwindow.cpp" line="626"/>
         <source>Copying desktop...ok</source>
-        <translation type="unfinished">Copie des bureaux...réussie</translation>
+        <translation>Copie des bureaux...réussie</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="630"/>
         <source>Synchronizing desktop...failed</source>
-        <translation type="unfinished">Synchronisation des bureaux...échec</translation>
+        <translation>Synchronisation des bureaux...échec</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="632"/>
         <source>Copying desktop...failed</source>
-        <translation type="unfinished">Copie des bureaux...échec</translation>
+        <translation>Copie des bureaux...échec</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="669"/>
         <location filename="../mainwindow.cpp" line="968"/>
         <location filename="../mainwindow.cpp" line="976"/>
         <source>browse...</source>
-        <translation type="unfinished">Navigation...</translation>
+        <translation>Navigation...</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="853"/>
         <source>About MX User Manager</source>
-        <translation type="unfinished">À propos de MX Gestionnaire des utilisateurs</translation>
+        <translation>À propos de MX Gestionnaire des utilisateurs</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="854"/>
         <source>MX User Manager</source>
-        <translation type="unfinished">MX Gestionnaire des utilisateurs</translation>
+        <translation>MX Gestionnaire des utilisateurs</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="856"/>
         <source>Simple user configuration for MX Linux</source>
-        <translation type="unfinished">Configuration simple des utilisateurs pour MX Linux </translation>
+        <translation>Configuration simple des utilisateurs pour MX Linux </translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="857"/>
         <source>Copyright (c) MX Linux</source>
-        <translation type="unfinished">Copyright (c) MX Linux</translation>
+        <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="858"/>
         <source>License</source>
-        <translation type="unfinished">Licence</translation>
+        <translation>Licence</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="859"/>
         <source>Changelog</source>
-        <translation type="unfinished">Journal des modifications</translation>
+        <translation>Journal des modifications</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="860"/>
         <source>Cancel</source>
-        <translation type="unfinished">Annuler</translation>
+        <translation>Annuler</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="876"/>
         <source>&amp;Close</source>
-        <translation type="unfinished">&amp;Fermer</translation>
+        <translation>&amp;Fermer</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="969"/>
         <source>Select folder to copy to</source>
-        <translation type="unfinished">Sélectionner le répertoire de destination</translation>
+        <translation>Sélectionner le répertoire de destination</translation>
     </message>
 </context>
 <context>
