@@ -1,153 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="hr">
-<context>
-    <name>MConfig</name>
-    <message>
-        <source>none</source>
-        <translation type="vanished">nijedan</translation>
-    </message>
-    <message>
-        <source>The user configuration will be repaired. Please close all other applications now. When finished, please logout or reboot. Are you sure you want to repair now?</source>
-        <translation type="vanished">Konfiguracija korisnika biti će popravljena, Molim zatvorite sve aplikacije. Kada bude završeno, molim odjavite se ili ponovno podignite sustav. Jeste li sigurni da želite popravljati sada?</translation>
-    </message>
-    <message>
-        <source>Yes</source>
-        <translation type="vanished">Da</translation>
-    </message>
-    <message>
-        <source>No</source>
-        <translation type="vanished">Ne</translation>
-    </message>
-    <message>
-        <source>Autologin options</source>
-        <translation type="vanished">Opcije samoprijave</translation>
-    </message>
-    <message>
-        <source>Autologin has been disabled for the &apos;%1&apos; account.</source>
-        <translation type="vanished">Automatska prijava je onemogućena za &apos;%1&apos; račun.</translation>
-    </message>
-    <message>
-        <source>Autologin has been enabled for the &apos;%1&apos; account.</source>
-        <translation type="vanished">Automatska prijava je omogućena za &apos;%1&apos; račun.</translation>
-    </message>
-    <message>
-        <source>You must specify a &apos;copy to&apos; destination. You cannot copy to the desktop you are logged in to.</source>
-        <translation type="vanished">Morate odrediti &apos;kopiraj u&apos; odredište. Ne možete kopirati u radno okruženje u koje ste prijavljeni.</translation>
-    </message>
-    <message>
-        <source>The user name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
-        <translation type="vanished">Korisničko ime mora biti barem 2 znaka dugo. Molim izaberite duže ime prije nego nastavite.</translation>
-    </message>
-    <message>
-        <source>The user name needs to be lower case and it
-cannot contain special characters or spaces.
-Please choose another name before proceeding.</source>
-        <translation type="vanished">Korisničko ime mora se sastojati od malih slova i ne
-smije sadržavati posebne znakove ili razmake.
-Molim odaberite drugo ime prije nastavka..</translation>
-    </message>
-    <message>
-        <source>Sorry that name is in use. Please select a different name.</source>
-        <translation type="vanished">Oprostite, ime je već u uporabi. Molim odaberite drugo ime.</translation>
-    </message>
-    <message>
-        <source>Password entries do not match. Please try again.</source>
-        <translation type="vanished">Unosi lozinke se ne podudaraju. Molim pokušajte ponovno.</translation>
-    </message>
-    <message>
-        <source>Password needs to be at least 2 characters long. Please enter a longer password before proceeding.</source>
-        <translation type="vanished">Lozinka mora biti barem 2 znaka duga. Molim izaberite dužu lozinku prije nego nastavite.</translation>
-    </message>
-    <message>
-        <source>The user was added ok.</source>
-        <translation type="vanished">Korisnik je uspješno dodan.</translation>
-    </message>
-    <message>
-        <source>Failed to add the user.</source>
-        <translation type="vanished">Neuspjelo dodavanje korisnika.</translation>
-    </message>
-    <message>
-        <source>Password successfully changed.</source>
-        <translation type="vanished">Lozinka je uspješno promijenjena.</translation>
-    </message>
-    <message>
-        <source>Failed to change password.</source>
-        <translation type="vanished">Neuspjela promjena lozinke.</translation>
-    </message>
-    <message>
-        <source>The user has been deleted.</source>
-        <translation type="vanished">Korisnik je izbrisan.</translation>
-    </message>
-    <message>
-        <source>Failed to delete the user.</source>
-        <translation type="vanished">Neuspjelo brisanje korisnika.</translation>
-    </message>
-    <message>
-        <source>The group name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
-        <translation type="vanished">Ima grupe mora biti barem 2 znaka dugo. Molim izaberite duže ime prije nego nastavite.</translation>
-    </message>
-    <message>
-        <source>The group name needs to be lower case and it 
-cannot contain special characters or spaces.
-Please choose another name before proceeding.</source>
-        <translation type="vanished">Ime grupe mora se sastojati od malih slova i ne
-smije sadržavati posebne znakove ili razmake.
-Molim odaberite drugo ime prije nastavka..</translation>
-    </message>
-    <message>
-        <source>Sorry that group name already exists. Please select a different name.</source>
-        <translation type="vanished">Oprostite, ime grupe je već u uporabi. Molim odaberite drugo ime.</translation>
-    </message>
-    <message>
-        <source>The system group was added ok.</source>
-        <translation type="vanished">Grupa sustava je uspješno dodana.</translation>
-    </message>
-    <message>
-        <source>Failed to add the system group.</source>
-        <translation type="vanished">Neuspjelo dodavanje grupe sustava.</translation>
-    </message>
-    <message>
-        <source>The group has been deleted.</source>
-        <translation type="vanished">Grupa je izbrisana.</translation>
-    </message>
-    <message>
-        <source>Failed to delete the group.</source>
-        <translation type="vanished">Neuspjelo brisanje grupe.</translation>
-    </message>
-    <message>
-        <source>The changes have been applied.</source>
-        <translation type="vanished">Promjene su primijenjene.</translation>
-    </message>
-    <message>
-        <source>Baobab installation</source>
-        <translation type="vanished">Baobab instalacija</translation>
-    </message>
-    <message>
-        <source>Wait while Baobab is installing...</source>
-        <translation type="vanished">Pričekajte dok se Baobab instalira...</translation>
-    </message>
-    <message>
-        <source>Copyright (c) MX Linux</source>
-        <translation type="vanished">Autorska prava (c) MX Linux</translation>
-    </message>
-    <message>
-        <source>License</source>
-        <translation type="vanished">Licenca</translation>
-    </message>
-    <message>
-        <source>Cancel</source>
-        <translation type="vanished">Otkaži</translation>
-    </message>
-    <message>
-        <source>&amp;Close</source>
-        <translation type="vanished">&amp;Zatvori</translation>
-    </message>
-    <message>
-        <source>Select folder to copy to</source>
-        <translation type="vanished">Odaberite mapu u koju ćete kopirati</translation>
-    </message>
-</context>
 <context>
     <name>MEConfig</name>
     <message>
@@ -230,37 +83,6 @@ Molim odaberite drugo ime prije nastavka..</translation>
         <source>Confirm user password:</source>
         <translation>Potvrdi korisničku lozinku:</translation>
     </message>
-    <message>
-        <location filename="../mainwindow.ui" line="432"/>
-        <source>Change User Password</source>
-        <translation>Promijeni korisničku lozinku</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="447"/>
-        <source>new password</source>
-        <translation>nova lozinka</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="460"/>
-        <source>Confirm new password:</source>
-        <translation>Potvrdi novu lozinku:</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="470"/>
-        <source>confirm new password</source>
-        <translation>potvrdi novu lozinku</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="371"/>
-        <location filename="../mainwindow.ui" line="483"/>
-        <source>Select user to modify:</source>
-        <translation>Odaberite korisnika kojeg ćete izmijeniti:</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="496"/>
-        <source>New user password:</source>
-        <translation>Lozinka novog korisnika:</translation>
-    </message>
     <message>
         <location filename="../mainwindow.ui" line="262"/>
         <source>Delete User Account</source>
@@ -300,11 +122,42 @@ Molim odaberite drugo ime prije nastavka..</translation>
         <source>Rename User Account</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../mainwindow.ui" line="371"/>
+        <location filename="../mainwindow.ui" line="483"/>
+        <source>Select user to modify:</source>
+        <translation>Odaberite korisnika kojeg ćete izmijeniti:</translation>
+    </message>
     <message>
         <location filename="../mainwindow.ui" line="403"/>
         <source>New user name:</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../mainwindow.ui" line="432"/>
+        <source>Change User Password</source>
+        <translation>Promijeni korisničku lozinku</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="447"/>
+        <source>new password</source>
+        <translation>nova lozinka</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="460"/>
+        <source>Confirm new password:</source>
+        <translation>Potvrdi novu lozinku:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="470"/>
+        <source>confirm new password</source>
+        <translation>potvrdi novu lozinku</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="496"/>
+        <source>New user password:</source>
+        <translation>Lozinka novog korisnika:</translation>
+    </message>
     <message>
         <location filename="../mainwindow.ui" line="527"/>
         <source>Options</source>
@@ -624,12 +477,12 @@ Molim odaberite drugo ime prije nastavka..</translation>
         <location filename="../mainwindow.cpp" line="916"/>
         <location filename="../mainwindow.cpp" line="1029"/>
         <source>none</source>
-        <translation type="unfinished">nijedan</translation>
+        <translation>nijedan</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="262"/>
         <source>The user configuration will be repaired. Please close all other applications now. When finished, please logout or reboot. Are you sure you want to repair now?</source>
-        <translation type="unfinished">Konfiguracija korisnika biti će popravljena, Molim zatvorite sve aplikacije. Kada bude završeno, molim odjavite se ili ponovno podignite sustav. Jeste li sigurni da želite popravljati sada?</translation>
+        <translation>Konfiguracija korisnika biti će popravljena, Molim zatvorite sve aplikacije. Kada bude završeno, molim odjavite se ili ponovno podignite sustav. Jeste li sigurni da želite popravljati sada?</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="263"/>
@@ -637,7 +490,7 @@ Molim odaberite drugo ime prije nastavka..</translation>
         <location filename="../mainwindow.cpp" line="439"/>
         <location filename="../mainwindow.cpp" line="494"/>
         <source>Yes</source>
-        <translation type="unfinished">Da</translation>
+        <translation>Da</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="263"/>
@@ -645,28 +498,28 @@ Molim odaberite drugo ime prije nastavka..</translation>
         <location filename="../mainwindow.cpp" line="439"/>
         <location filename="../mainwindow.cpp" line="494"/>
         <source>No</source>
-        <translation type="unfinished">Ne</translation>
+        <translation>Ne</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="284"/>
         <location filename="../mainwindow.cpp" line="295"/>
         <source>Autologin options</source>
-        <translation type="unfinished">Opcije samoprijave</translation>
+        <translation>Opcije automatske prijave</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="285"/>
         <source>Autologin has been disabled for the &apos;%1&apos; account.</source>
-        <translation type="unfinished">Automatska prijava je onemogućena za &apos;%1&apos; račun.</translation>
+        <translation>Automatska prijava je onemogućena za &apos;%1&apos; račun.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="296"/>
         <source>Autologin has been enabled for the &apos;%1&apos; account.</source>
-        <translation type="unfinished">Automatska prijava je omogućena za &apos;%1&apos; račun.</translation>
+        <translation>Automatska prijava je omogućena za &apos;%1&apos; račun.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="307"/>
         <source>You must specify a &apos;copy to&apos; destination. You cannot copy to the desktop you are logged in to.</source>
-        <translation type="unfinished">Morate odrediti &apos;kopiraj u&apos; odredište. Ne možete kopirati u radno okruženje u koje ste prijavljeni.</translation>
+        <translation>Morate odrediti &apos;kopiraj u&apos; odredište. Ne možete kopirati u radno okruženje u koje ste prijavljeni.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="311"/>
@@ -687,7 +540,7 @@ Molim odaberite drugo ime prije nastavka..</translation>
         <location filename="../mainwindow.cpp" line="356"/>
         <location filename="../mainwindow.cpp" line="548"/>
         <source>The user name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
-        <translation type="unfinished">Korisničko ime mora biti barem 2 znaka dugo. Molim izaberite duže ime prije nego nastavite.</translation>
+        <translation>Korisničko ime mora biti barem 2 znaka dugo. Molim izaberite duže ime prije nego nastavite.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="360"/>
@@ -695,45 +548,46 @@ Molim odaberite drugo ime prije nastavka..</translation>
         <source>The user name needs to be lower case and it
 cannot contain special characters or spaces.
 Please choose another name before proceeding.</source>
-        <translation type="unfinished">Korisničko ime mora se sastojati od malih slova i ne
+        <translation>Korisničko ime mora se sastojati od malih slova i ne
 smije sadržavati posebne znakove ili razmake.
 Molim odaberite drugo ime prije nastavka..</translation>
     </message>
     <message>
-        <source>Sorry that name is in use. Please select a different name.</source>
-        <translation type="obsolete">Oprostite, ime je već u uporabi. Molim odaberite drugo ime.</translation>
+        <location filename="../mainwindow.cpp" line="369"/>
+        <source>Sorry, this name is in use. Please enter a different name.</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="374"/>
         <location filename="../mainwindow.cpp" line="409"/>
         <source>Password entries do not match. Please try again.</source>
-        <translation type="unfinished">Unosi lozinke se ne podudaraju. Molim pokušajte ponovno.</translation>
+        <translation>Unosi lozinke se ne podudaraju. Molim pokušajte ponovno.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="379"/>
         <location filename="../mainwindow.cpp" line="414"/>
         <source>Password needs to be at least 2 characters long. Please enter a longer password before proceeding.</source>
-        <translation type="unfinished">Lozinka mora biti barem 2 znaka duga. Molim izaberite dužu lozinku prije nego nastavite.</translation>
+        <translation>Lozinka mora biti barem 2 znaka duga. Molim izaberite dužu lozinku prije nego nastavite.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="396"/>
         <source>The user was added ok.</source>
-        <translation type="unfinished">Korisnik je uspješno dodan.</translation>
+        <translation>Korisnik je uspješno dodan.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="400"/>
         <source>Failed to add the user.</source>
-        <translation type="unfinished">Neuspjelo dodavanje korisnika.</translation>
+        <translation>Neuspjelo dodavanje korisnika.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="428"/>
         <source>Password successfully changed.</source>
-        <translation type="unfinished">Lozinka je uspješno promijenjena.</translation>
+        <translation>Lozinka je uspješno promijenjena.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="432"/>
         <source>Failed to change password.</source>
-        <translation type="unfinished">Neuspjela promjena lozinke.</translation>
+        <translation>Neuspjela promjena lozinke.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="437"/>
@@ -743,40 +597,41 @@ Molim odaberite drugo ime prije nastavka..</translation>
     <message>
         <location filename="../mainwindow.cpp" line="450"/>
         <source>The user has been deleted.</source>
-        <translation type="unfinished">Korisnik je izbrisan.</translation>
+        <translation>Korisnik je izbrisan.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="453"/>
         <source>Failed to delete the user.</source>
-        <translation type="unfinished">Neuspjelo brisanje korisnika.</translation>
+        <translation>Neuspjelo brisanje korisnika.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="466"/>
         <source>The group name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
-        <translation type="unfinished">Ima grupe mora biti barem 2 znaka dugo. Molim izaberite duže ime prije nego nastavite.</translation>
+        <translation>Ima grupe mora biti barem 2 znaka dugo. Molim izaberite duže ime prije nego nastavite.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="470"/>
         <source>The group name needs to be lower case and it 
 cannot contain special characters or spaces.
 Please choose another name before proceeding.</source>
-        <translation type="unfinished">Ime grupe mora se sastojati od malih slova i ne
+        <translation>Ime grupe mora se sastojati od malih slova i ne
 smije sadržavati posebne znakove ili razmake.
 Molim odaberite drugo ime prije nastavka..</translation>
     </message>
     <message>
-        <source>Sorry that group name already exists. Please select a different name.</source>
-        <translation type="obsolete">Oprostite, ime grupe je već u uporabi. Molim odaberite drugo ime.</translation>
+        <location filename="../mainwindow.cpp" line="479"/>
+        <source>Sorry, that group name already exists. Please enter a different name.</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="486"/>
         <source>The system group was added ok.</source>
-        <translation type="unfinished">Grupa sustava je uspješno dodana.</translation>
+        <translation>Grupa sustava je uspješno dodana.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="489"/>
         <source>Failed to add the system group.</source>
-        <translation type="unfinished">Neuspjelo dodavanje grupe sustava.</translation>
+        <translation>Neuspjelo dodavanje grupe sustava.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="492"/>
@@ -786,17 +641,17 @@ Molim odaberite drugo ime prije nastavka..</translation>
     <message>
         <location filename="../mainwindow.cpp" line="499"/>
         <source>The group has been deleted.</source>
-        <translation type="unfinished">Grupa je izbrisana.</translation>
+        <translation>Grupa je izbrisana.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="502"/>
         <source>Failed to delete the group.</source>
-        <translation type="unfinished">Neuspjelo brisanje grupe.</translation>
+        <translation>Neuspjelo brisanje grupe.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="523"/>
         <source>The changes have been applied.</source>
-        <translation type="unfinished">Promjene su primijenjene.</translation>
+        <translation>Promjene su primijenjene.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="526"/>
@@ -813,16 +668,6 @@ Molim odaberite drugo ime prije nastavka..</translation>
         <source>To rename this user, please log out and log back in using another user account.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="369"/>
-        <source>Sorry, this name is in use. Please enter a different name.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="479"/>
-        <source>Sorry, that group name already exists. Please enter a different name.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../mainwindow.cpp" line="561"/>
         <source>Sorry, this name already exists on your system. Please enter a different name.</source>
@@ -885,12 +730,12 @@ Molim odaberite drugo ime prije nastavka..</translation>
     <message>
         <location filename="../mainwindow.cpp" line="857"/>
         <source>Copyright (c) MX Linux</source>
-        <translation type="unfinished">Autorska prava (c) MX Linux</translation>
+        <translation>Autorska prava (c) MX Linux</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="858"/>
         <source>License</source>
-        <translation type="unfinished">Licenca</translation>
+        <translation>Licenca</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="859"/>
@@ -900,17 +745,17 @@ Molim odaberite drugo ime prije nastavka..</translation>
     <message>
         <location filename="../mainwindow.cpp" line="860"/>
         <source>Cancel</source>
-        <translation type="unfinished">Otkaži</translation>
+        <translation>Otkaži</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="876"/>
         <source>&amp;Close</source>
-        <translation type="unfinished">&amp;Zatvori</translation>
+        <translation>&amp;Zatvori</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="969"/>
         <source>Select folder to copy to</source>
-        <translation type="unfinished">Odaberite mapu u koju ćete kopirati</translation>
+        <translation>Odaberite mapu u koju ćete kopirati</translation>
     </message>
 </context>
 <context>
