@@ -1,213 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="pt">
-<context>
-    <name>MConfig</name>
-    <message>
-        <source>none</source>
-        <translation type="vanished">nenhuma</translation>
-    </message>
-    <message>
-        <source>The user configuration will be repaired. Please close all other applications now. When finished, please logout or reboot. Are you sure you want to repair now?</source>
-        <translation type="vanished">A configuração de utilizador será reparada. Feche todas as outras aplicações agora. Quando concluído, saia da sessão ou reinicie. Pretende fazer a reparação agora?</translation>
-    </message>
-    <message>
-        <source>Yes</source>
-        <translation type="vanished">Sim</translation>
-    </message>
-    <message>
-        <source>No</source>
-        <translation type="vanished">Não</translation>
-    </message>
-    <message>
-        <source>Autologin options</source>
-        <translation type="vanished">Opções de acesso automático</translation>
-    </message>
-    <message>
-        <source>Autologin has been disabled for the &apos;%1&apos; account.</source>
-        <translation type="vanished">O acesso automático foi desativado para  a conta &apos;%1&apos;.</translation>
-    </message>
-    <message>
-        <source>Autologin has been enabled for the &apos;%1&apos; account.</source>
-        <translation type="vanished">O acesso automático foi ativado para  a conta &apos;%1&apos;.</translation>
-    </message>
-    <message>
-        <source>You must specify a &apos;copy to&apos; destination. You cannot copy to the desktop you are logged in to.</source>
-        <translation type="vanished">Tem que especificar um destino para &apos;copiar para&apos;. Não pode copiar para o ambiente de trabalho da sessão.</translation>
-    </message>
-    <message>
-        <source>Before copying, close all other applications. Be sure the copy to destination is large enough to contain the files you are copying. Copying between desktops may overwrite or delete your files or preferences on the destination desktop. Are you sure you want to proceed?</source>
-        <translation type="vanished">Antes de copiar, feche todas as outras aplicações. Certifique-se de que o destino de &apos;copiar para&apos; é suficientemente grande para receber todos os ficheiros a copiar. copiar entre ambientes de trabalho pode escrever por cima de, ou apagar, ficheiros ou preferências no ambiente de trabalho de destino. Pretende continuar?</translation>
-    </message>
-    <message>
-        <source>Synchronizing desktop...</source>
-        <translation type="vanished">A sincronizar ambiente de trabalho...</translation>
-    </message>
-    <message>
-        <source>Copying desktop...</source>
-        <translation type="vanished">A copiar o ambiente de trabalho...</translation>
-    </message>
-    <message>
-        <source>The user name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
-        <translation type="vanished">O nome de utilizador tem que ter pelo menos 2 caracteres. Escolha um nome de utilizador mais comprido.</translation>
-    </message>
-    <message>
-        <source>The user name needs to be lower case and it
-cannot contain special characters or spaces.
-Please choose another name before proceeding.</source>
-        <translation type="vanished">O nome de utilizador tem que estar em minúsculas
-e não pode conter caracteres especiais ou espaços.
-Escolha outro nome de utilizador.</translation>
-    </message>
-    <message>
-        <source>Sorry that name is in use. Please select a different name.</source>
-        <translation type="vanished">Este nome está em uso. Escolha outro nome.</translation>
-    </message>
-    <message>
-        <source>Password entries do not match. Please try again.</source>
-        <translation type="vanished">As senhas não coincidem. Tente de novo.</translation>
-    </message>
-    <message>
-        <source>Password needs to be at least 2 characters long. Please enter a longer password before proceeding.</source>
-        <translation type="vanished">A senha tem que ter pelo menos 2 caracteres. Escolha uma senha mais longa.</translation>
-    </message>
-    <message>
-        <source>The user was added ok.</source>
-        <translation type="vanished">O utilizador foi adicionado.</translation>
-    </message>
-    <message>
-        <source>Failed to add the user.</source>
-        <translation type="vanished">A adição do utilizador falhou.</translation>
-    </message>
-    <message>
-        <source>Password successfully changed.</source>
-        <translation type="vanished">A senha foi alterada.</translation>
-    </message>
-    <message>
-        <source>Failed to change password.</source>
-        <translation type="vanished">Falha na alteração da senha.</translation>
-    </message>
-    <message>
-        <source>This action cannot be undone. Are you sure you want to delete user %1?</source>
-        <translation type="vanished">Esta acção não pode ser revertida. Tem a certeza de que pretende eliminar o utilizador %1?</translation>
-    </message>
-    <message>
-        <source>The user has been deleted.</source>
-        <translation type="vanished">O utilizador foi eliminado.</translation>
-    </message>
-    <message>
-        <source>Failed to delete the user.</source>
-        <translation type="vanished">A eliminação do utilizador falhou.</translation>
-    </message>
-    <message>
-        <source>The group name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
-        <translation type="vanished">O nome de grupo tem que ter pelo menos 2 caracteres. Escolha um nome mais comprido.</translation>
-    </message>
-    <message>
-        <source>The group name needs to be lower case and it 
-cannot contain special characters or spaces.
-Please choose another name before proceeding.</source>
-        <translation type="vanished">O nome de grupo tem que estar em minúsculas
-e não pode conter carácteres especiais ou espaços.
-Escolha outro nome de utilizador.</translation>
-    </message>
-    <message>
-        <source>Sorry that group name already exists. Please select a different name.</source>
-        <translation type="vanished">Este nome de grupo já existe. Escolha outro nome.</translation>
-    </message>
-    <message>
-        <source>The system group was added ok.</source>
-        <translation type="vanished">O grupo foi addicionado.</translation>
-    </message>
-    <message>
-        <source>Failed to add the system group.</source>
-        <translation type="vanished">A adição do grupo falhou.</translation>
-    </message>
-    <message>
-        <source>This action cannot be undone. Are you sure you want to delete group %1?</source>
-        <translation type="vanished">Esta accção não pode ser revertida. Tem a certeza de que pretende eliminar o utilizador %1?</translation>
-    </message>
-    <message>
-        <source>The group has been deleted.</source>
-        <translation type="vanished">O grupo foi eliminado.</translation>
-    </message>
-    <message>
-        <source>Failed to delete the group.</source>
-        <translation type="vanished">A eliminação do grupo falhou.</translation>
-    </message>
-    <message>
-        <source>The changes have been applied.</source>
-        <translation type="vanished">As alterações foram aplicadas.</translation>
-    </message>
-    <message>
-        <source>Failed to apply group changes</source>
-        <translation type="vanished">A aplicação das alterações falhou</translation>
-    </message>
-    <message>
-        <source>Synchronizing desktop...ok</source>
-        <translation type="vanished">A sincronizar ambiente de trabalho... concluído.</translation>
-    </message>
-    <message>
-        <source>Copying desktop...ok</source>
-        <translation type="vanished">A copiar ambiente de trabalho... concluído.</translation>
-    </message>
-    <message>
-        <source>Synchronizing desktop...failed</source>
-        <translation type="vanished">A sincronizar ambiente de trabalho... falhou</translation>
-    </message>
-    <message>
-        <source>Copying desktop...failed</source>
-        <translation type="vanished">A copiar ambiente de trabalho... falhou</translation>
-    </message>
-    <message>
-        <source>browse...</source>
-        <translation type="vanished">percorrer...</translation>
-    </message>
-    <message>
-        <source>Baobab installation</source>
-        <translation type="vanished">Instalação do Baobab</translation>
-    </message>
-    <message>
-        <source>Wait while Baobab is installing...</source>
-        <translation type="vanished">Aguarde enquanto o Baobab é instalado... </translation>
-    </message>
-    <message>
-        <source>About MX User Manager</source>
-        <translation type="vanished">Sobre o MX_Gestor de utilizadores</translation>
-    </message>
-    <message>
-        <source>MX User Manager</source>
-        <translation type="vanished">MX_Gestor de utilizadores</translation>
-    </message>
-    <message>
-        <source>Simple user configuration for MX Linux</source>
-        <translation type="vanished">Conficuração simples de utilizador para o Linux MX</translation>
-    </message>
-    <message>
-        <source>Copyright (c) MX Linux</source>
-        <translation type="vanished">Copyright (c) MX Linux</translation>
-    </message>
-    <message>
-        <source>License</source>
-        <translation type="vanished">Licença</translation>
-    </message>
-    <message>
-        <source>Changelog</source>
-        <translation type="vanished">Registo de alterações</translation>
-    </message>
-    <message>
-        <source>Cancel</source>
-        <translation type="vanished">Cancelar</translation>
-    </message>
-    <message>
-        <source>&amp;Close</source>
-        <translation type="vanished">&amp;Fechar</translation>
-    </message>
-    <message>
-        <source>Select folder to copy to</source>
-        <translation type="vanished">Seleccionar pasta para onde copiar</translation>
-    </message>
-</context>
 <context>
     <name>MEConfig</name>
     <message>
@@ -290,47 +83,6 @@ Escolha outro nome de utilizador.</translation>
         <source>Confirm user password:</source>
         <translation>Confirmar a senha do utilizador:</translation>
     </message>
-    <message>
-        <location filename="../mainwindow.ui" line="359"/>
-        <source>Rename User Account</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="403"/>
-        <source>New user name:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="432"/>
-        <source>Change User Password</source>
-        <translation>Alterar a Senha de Utilizador</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="447"/>
-        <source>new password</source>
-        <translation>nova senha</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="460"/>
-        <source>Confirm new password:</source>
-        <translation>Confirmar a nova senha:</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="470"/>
-        <source>confirm new password</source>
-        <translation>confirmar a nova senha</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="371"/>
-        <location filename="../mainwindow.ui" line="483"/>
-        <source>Select user to modify:</source>
-        <translation>Seleccionar o utilizador a modificar:</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="496"/>
-        <source>New user password:</source>
-        <translation>Nova senha de utilizador:</translation>
-    </message>
     <message>
         <location filename="../mainwindow.ui" line="262"/>
         <source>Delete User Account</source>
@@ -365,6 +117,47 @@ Escolha outro nome de utilizador.</translation>
         <source>Delete user home directory</source>
         <translation>Eliminar a directoria &apos;home&apos; do utilizador</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.ui" line="359"/>
+        <source>Rename User Account</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="371"/>
+        <location filename="../mainwindow.ui" line="483"/>
+        <source>Select user to modify:</source>
+        <translation>Seleccionar o utilizador a modificar:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="403"/>
+        <source>New user name:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="432"/>
+        <source>Change User Password</source>
+        <translation>Alterar a Senha de Utilizador</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="447"/>
+        <source>new password</source>
+        <translation>nova senha</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="460"/>
+        <source>Confirm new password:</source>
+        <translation>Confirmar a nova senha:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="470"/>
+        <source>confirm new password</source>
+        <translation>confirmar a nova senha</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="496"/>
+        <source>New user password:</source>
+        <translation>Nova senha de utilizador:</translation>
+    </message>
     <message>
         <location filename="../mainwindow.ui" line="527"/>
         <source>Options</source>
@@ -428,14 +221,6 @@ Escolha outro nome de utilizador.</translation>
         <source>Alt+G</source>
         <translation>Alt+G</translation>
     </message>
-    <message>
-        <source>Restore APT sources to MX defaults</source>
-        <translation type="vanished">Restabelecer as funcionalidades APT para as pré-definições do MX </translation>
-    </message>
-    <message>
-        <source>Restore APT sources</source>
-        <translation type="vanished">Restablecer as funcionalidades APT</translation>
-    </message>
     <message>
         <location filename="../mainwindow.ui" line="680"/>
         <source>Change Autologin Settings</source>
@@ -692,12 +477,12 @@ Escolha outro nome de utilizador.</translation>
         <location filename="../mainwindow.cpp" line="916"/>
         <location filename="../mainwindow.cpp" line="1029"/>
         <source>none</source>
-        <translation type="unfinished">nenhuma</translation>
+        <translation>nenhuma</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="262"/>
         <source>The user configuration will be repaired. Please close all other applications now. When finished, please logout or reboot. Are you sure you want to repair now?</source>
-        <translation type="unfinished">A configuração de utilizador será reparada. Feche todas as outras aplicações agora. Quando concluído, saia da sessão ou reinicie. Pretende fazer a reparação agora?</translation>
+        <translation>A configuração de utilizador será reparada. Fechar todas as outras aplicações agora. Quando concluído, sair da sessão ou reiniciar. Proceder à reparação agora?</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="263"/>
@@ -705,7 +490,7 @@ Escolha outro nome de utilizador.</translation>
         <location filename="../mainwindow.cpp" line="439"/>
         <location filename="../mainwindow.cpp" line="494"/>
         <source>Yes</source>
-        <translation type="unfinished">Sim</translation>
+        <translation>Sim</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="263"/>
@@ -713,49 +498,49 @@ Escolha outro nome de utilizador.</translation>
         <location filename="../mainwindow.cpp" line="439"/>
         <location filename="../mainwindow.cpp" line="494"/>
         <source>No</source>
-        <translation type="unfinished">Não</translation>
+        <translation>Não</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="284"/>
         <location filename="../mainwindow.cpp" line="295"/>
         <source>Autologin options</source>
-        <translation type="unfinished">Opções de acesso automático</translation>
+        <translation>Opções de acesso automático</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="285"/>
         <source>Autologin has been disabled for the &apos;%1&apos; account.</source>
-        <translation type="unfinished">O acesso automático foi desativado para  a conta &apos;%1&apos;.</translation>
+        <translation>O acesso automático foi desativado para  a conta &apos;%1&apos;.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="296"/>
         <source>Autologin has been enabled for the &apos;%1&apos; account.</source>
-        <translation type="unfinished">O acesso automático foi ativado para  a conta &apos;%1&apos;.</translation>
+        <translation>O acesso automático foi ativado para  a conta &apos;%1&apos;.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="307"/>
         <source>You must specify a &apos;copy to&apos; destination. You cannot copy to the desktop you are logged in to.</source>
-        <translation type="unfinished">Tem que especificar um destino para &apos;copiar para&apos;. Não pode copiar para o ambiente de trabalho da sessão.</translation>
+        <translation>É necessário especificar um destino onde &apos;copiar para&apos;. Não se pode copiar para o ambiente de trabalho da sessão.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="311"/>
         <source>Before copying, close all other applications. Be sure the copy to destination is large enough to contain the files you are copying. Copying between desktops may overwrite or delete your files or preferences on the destination desktop. Are you sure you want to proceed?</source>
-        <translation type="unfinished">Antes de copiar, feche todas as outras aplicações. Certifique-se de que o destino de &apos;copiar para&apos; é suficientemente grande para receber todos os ficheiros a copiar. copiar entre ambientes de trabalho pode escrever por cima de, ou apagar, ficheiros ou preferências no ambiente de trabalho de destino. Pretende continuar?</translation>
+        <translation>Antes de copiar, feche todas as outras aplicações. Certifique-se de que o destino de &apos;copiar para&apos; é suficientemente grande para receber todos os ficheiros a copiar. copiar entre ambientes de trabalho pode escrever por cima de, ou apagar, ficheiros ou preferências no ambiente de trabalho de destino. Pretende continuar?</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="336"/>
         <source>Synchronizing desktop...</source>
-        <translation type="unfinished">A sincronizar ambiente de trabalho...</translation>
+        <translation>A sincronizar ambiente de trabalho...</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="338"/>
         <source>Copying desktop...</source>
-        <translation type="unfinished">A copiar o ambiente de trabalho...</translation>
+        <translation>A copiar o ambiente de trabalho...</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="356"/>
         <location filename="../mainwindow.cpp" line="548"/>
         <source>The user name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
-        <translation type="unfinished">O nome de utilizador tem que ter pelo menos 2 caracteres. Escolha um nome de utilizador mais comprido.</translation>
+        <translation>O nome de utilizador tem que ter pelo menos 2 caracteres. Escolha um nome de utilizador mais comprido.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="360"/>
@@ -763,113 +548,115 @@ Escolha outro nome de utilizador.</translation>
         <source>The user name needs to be lower case and it
 cannot contain special characters or spaces.
 Please choose another name before proceeding.</source>
-        <translation type="unfinished">O nome de utilizador tem que estar em minúsculas
+        <translation>O nome de utilizador tem que estar em minúsculas
 e não pode conter caracteres especiais ou espaços.
 Escolha outro nome de utilizador.</translation>
     </message>
     <message>
-        <source>Sorry that name is in use. Please select a different name.</source>
-        <translation type="obsolete">Este nome está em uso. Escolha outro nome.</translation>
+        <location filename="../mainwindow.cpp" line="369"/>
+        <source>Sorry, this name is in use. Please enter a different name.</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="374"/>
         <location filename="../mainwindow.cpp" line="409"/>
         <source>Password entries do not match. Please try again.</source>
-        <translation type="unfinished">As senhas não coincidem. Tente de novo.</translation>
+        <translation>As senhas não coincidem. Tente de novo.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="379"/>
         <location filename="../mainwindow.cpp" line="414"/>
         <source>Password needs to be at least 2 characters long. Please enter a longer password before proceeding.</source>
-        <translation type="unfinished">A senha tem que ter pelo menos 2 caracteres. Escolha uma senha mais longa.</translation>
+        <translation>A senha tem que ter pelo menos 2 caracteres. Escolha uma senha mais longa.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="396"/>
         <source>The user was added ok.</source>
-        <translation type="unfinished">O utilizador foi adicionado.</translation>
+        <translation>O utilizador foi adicionado.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="400"/>
         <source>Failed to add the user.</source>
-        <translation type="unfinished">A adição do utilizador falhou.</translation>
+        <translation>A adição do utilizador falhou.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="428"/>
         <source>Password successfully changed.</source>
-        <translation type="unfinished">A senha foi alterada.</translation>
+        <translation>A senha foi alterada.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="432"/>
         <source>Failed to change password.</source>
-        <translation type="unfinished">Falha na alteração da senha.</translation>
+        <translation>Falha na alteração da senha.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="437"/>
         <source>This action cannot be undone. Are you sure you want to delete user %1?</source>
-        <translation type="unfinished">Esta acção não pode ser revertida. Tem a certeza de que pretende eliminar o utilizador %1?</translation>
+        <translation>Esta acção não pode ser revertida. Tem a certeza de que pretende eliminar o utilizador %1?</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="450"/>
         <source>The user has been deleted.</source>
-        <translation type="unfinished">O utilizador foi eliminado.</translation>
+        <translation>O utilizador foi eliminado.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="453"/>
         <source>Failed to delete the user.</source>
-        <translation type="unfinished">A eliminação do utilizador falhou.</translation>
+        <translation>A eliminação do utilizador falhou.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="466"/>
         <source>The group name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
-        <translation type="unfinished">O nome de grupo tem que ter pelo menos 2 caracteres. Escolha um nome mais comprido.</translation>
+        <translation>O nome de grupo tem que ter pelo menos 2 caracteres. Escolha um nome mais comprido.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="470"/>
         <source>The group name needs to be lower case and it 
 cannot contain special characters or spaces.
 Please choose another name before proceeding.</source>
-        <translation type="unfinished">O nome de grupo tem que estar em minúsculas
+        <translation>O nome de grupo tem que estar em minúsculas
 e não pode conter carácteres especiais ou espaços.
 Escolha outro nome de utilizador.</translation>
     </message>
     <message>
-        <source>Sorry that group name already exists. Please select a different name.</source>
-        <translation type="obsolete">Este nome de grupo já existe. Escolha outro nome.</translation>
+        <location filename="../mainwindow.cpp" line="479"/>
+        <source>Sorry, that group name already exists. Please enter a different name.</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="486"/>
         <source>The system group was added ok.</source>
-        <translation type="unfinished">O grupo foi addicionado.</translation>
+        <translation>O grupo foi addicionado.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="489"/>
         <source>Failed to add the system group.</source>
-        <translation type="unfinished">A adição do grupo falhou.</translation>
+        <translation>A adição do grupo falhou.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="492"/>
         <source>This action cannot be undone. Are you sure you want to delete group %1?</source>
-        <translation type="unfinished">Esta accção não pode ser revertida. Tem a certeza de que pretende eliminar o utilizador %1?</translation>
+        <translation>Esta accção não pode ser revertida. Tem a certeza de que pretende eliminar o utilizador %1?</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="499"/>
         <source>The group has been deleted.</source>
-        <translation type="unfinished">O grupo foi eliminado.</translation>
+        <translation>O grupo foi eliminado.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="502"/>
         <source>Failed to delete the group.</source>
-        <translation type="unfinished">A eliminação do grupo falhou.</translation>
+        <translation>A eliminação do grupo falhou.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="523"/>
         <source>The changes have been applied.</source>
-        <translation type="unfinished">As alterações foram aplicadas.</translation>
+        <translation>As alterações foram aplicadas.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="526"/>
         <source>Failed to apply group changes</source>
-        <translation type="unfinished">A aplicação das alterações falhou</translation>
+        <translation>A aplicação das alterações falhou</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="539"/>
@@ -881,16 +668,6 @@ Escolha outro nome de utilizador.</translation>
         <source>To rename this user, please log out and log back in using another user account.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="369"/>
-        <source>Sorry, this name is in use. Please enter a different name.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="479"/>
-        <source>Sorry, that group name already exists. Please enter a different name.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../mainwindow.cpp" line="561"/>
         <source>Sorry, this name already exists on your system. Please enter a different name.</source>
@@ -910,75 +687,75 @@ Escolha outro nome de utilizador.</translation>
         <location filename="../mainwindow.cpp" line="595"/>
         <location filename="../mainwindow.cpp" line="624"/>
         <source>Synchronizing desktop...ok</source>
-        <translation type="unfinished">A sincronizar ambiente de trabalho... concluído.</translation>
+        <translation>A sincronizar ambiente de trabalho... concluído.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="597"/>
         <location filename="../mainwindow.cpp" line="626"/>
         <source>Copying desktop...ok</source>
-        <translation type="unfinished">A copiar ambiente de trabalho... concluído.</translation>
+        <translation>A copiar ambiente de trabalho... concluído.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="630"/>
         <source>Synchronizing desktop...failed</source>
-        <translation type="unfinished">A sincronizar ambiente de trabalho... falhou</translation>
+        <translation>A sincronizar ambiente de trabalho... falhou</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="632"/>
         <source>Copying desktop...failed</source>
-        <translation type="unfinished">A copiar ambiente de trabalho... falhou</translation>
+        <translation>A copiar ambiente de trabalho... falhou</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="669"/>
         <location filename="../mainwindow.cpp" line="968"/>
         <location filename="../mainwindow.cpp" line="976"/>
         <source>browse...</source>
-        <translation type="unfinished">percorrer...</translation>
+        <translation>percorrer...</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="853"/>
         <source>About MX User Manager</source>
-        <translation type="unfinished">Sobre o MX_Gestor de utilizadores</translation>
+        <translation>Sobre o MX_Gestor de utilizadores</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="854"/>
         <source>MX User Manager</source>
-        <translation type="unfinished"></translation>
+        <translation>Gestor de utilizadores MX</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="856"/>
         <source>Simple user configuration for MX Linux</source>
-        <translation type="unfinished">Conficuração simples de utilizador para o Linux MX</translation>
+        <translation>Conficuração simples de utilizador para o Linux MX</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="857"/>
         <source>Copyright (c) MX Linux</source>
-        <translation type="unfinished">Copyright (c) MX Linux</translation>
+        <translation>Direitos de autor (c) MX Linux</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="858"/>
         <source>License</source>
-        <translation type="unfinished">Licença</translation>
+        <translation>Licença</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="859"/>
         <source>Changelog</source>
-        <translation type="unfinished">Registo de alterações</translation>
+        <translation>Registo de alterações</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="860"/>
         <source>Cancel</source>
-        <translation type="unfinished">Cancelar</translation>
+        <translation>Cancelar</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="876"/>
         <source>&amp;Close</source>
-        <translation type="unfinished">&amp;Fechar</translation>
+        <translation>&amp;Fechar</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="969"/>
         <source>Select folder to copy to</source>
-        <translation type="unfinished">Seleccionar pasta para onde copiar</translation>
+        <translation>Seleccionar pasta para onde copiar</translation>
     </message>
 </context>
 <context>
